Module substrait_expr::builder::functions
source · Structs
- A builder object to create a scalar function expression
- This is a rust equivalent of a YAML function definition
- A potential implementation of a function
- A builder that can create scalar function expressions
- A named function argument
Enums
- Represents a function argument
Constants
- The name of the special function we use to indicate a late lookup
- The URI of the special function we use to indicate a late lookup