Enum substrait_expr::builder::functions::FunctionReturn
source · pub enum FunctionReturn {
Templated(String),
Typed(Type),
Program(),
}Variants
Templated(String)
The return value of the function is a templated type (e.g. add
Typed(Type)
The return value of the function is a fixed type (e.g. add(u32, u32) -> u32)
Program()
The return value of the function is a program (e.g. add(Decimal<P1,S1>, Decimal<P2,S2>) -> …)