pub enum ImplementationArgType {
TemplateValue(String),
Enum(Vec<String>),
Value(Type),
}Expand description
Represents a function argument
Variants
TemplateValue(String)
An argument is a templated value (e.g. add
Enum(Vec<String>)
The argument is a constant choice between a small set of possible values
For example, the “extract” function uses an enum to select the field to extract from a datetime value.
Value(Type)
A regular argument provided by an expression of the given type