Struct substrait_expr::builder::functions::FunctionBuilder
source · pub struct FunctionBuilder<'a> { /* private fields */ }Expand description
A builder object to create a scalar function expression
This can be used to parameterize the function call with options
Implementations
sourceimpl<'a> FunctionBuilder<'a>
impl<'a> FunctionBuilder<'a>
sourcepub fn build(self) -> Result<Expression, SubstraitExprError>
pub fn build(self) -> Result<Expression, SubstraitExprError>
Consume the builder and create a function expression