pub struct FunctionDefinition {
    pub uri: String,
    pub name: String,
    pub implementations: Vec<FunctionImplementation>,
}
This is a rust equivalent of a YAML function definition

We chose to use mirror types here as the YAML schema is still a little loose and we wanted something simpler. The full types can be obtained using the substrait library and serde_yaml.

Fields

uri: String

The URI of the function

Note: this is the one field that is not actually present in the YAML but is generally the URI of the YAML itself

name: String

The name of the function

implementations: Vec<FunctionImplementation>

The various implementation kernels supported by the function

Implementations

source

impl FunctionDefinition

source

pub fn pick_implementation_from_args( &self, args: &[Expression], schema: &SchemaInfo ) -> Result<Option<FunctionImplementation>, SubstraitExprError>

Given input expressions this attempts to find a matching implementation

This is still very experimental and the implementation resolution rules are subject to change.

Currently this looks for an implementation that exactly matches the input expressions’ types. If any of the input types are the unknown type then those arguments are considered matching but the return type is changed to unknown.