Struct substrait_expr::builder::functions::FunctionImplementation
source · pub struct FunctionImplementation {
pub args: Vec<ImplementationArg>,
pub output_type: FunctionReturn,
}Expand description
A potential implementation of a function
Fields
args: Vec<ImplementationArg>The input arguments
output_type: FunctionReturnThe type that should be output from the function
Implementations
sourceimpl FunctionImplementation
impl FunctionImplementation
sourcepub fn matches(&self, arg_types: &[Type], registry: &ExtensionsRegistry) -> bool
pub fn matches(&self, arg_types: &[Type], registry: &ExtensionsRegistry) -> bool
Returns true if expressions with types specified by arg_types would match this implementation