pub struct FunctionsBuilder<'a> { /* private fields */ }
A builder that can create scalar function expressions

Implementations

source

impl<'a> FunctionsBuilder<'a>

source

pub fn new_builder( &self, func: &'static FunctionDefinition, args: Vec<Expression> ) -> FunctionBuilder<'_>

Creates a new FunctionBuilder based on a given function definition.

This method is not typically used directly. Instead, extension functions like add or subtract are used which call this function.

However, this could be used directly for UDFs if you don’t want to create an extension trait.

source

pub fn lookup_field_by_name(&self, name: impl Into<String>) -> Expression

Creates a “late lookup” function expression

This is not really a function call. It’s a placeholder we are currently using to indicate an unresolved field reference. This is created whenever a user creates a field reference by name but the schema is unknown or does not know names.