pub struct ImplementationArg {
    pub name: String,
    pub arg_type: ImplementationArgType,
}
A named function argument

Fields

name: String

The name of the argument

This is used for documentation and readability purposes. Consumers don’t generally care what the name is.

arg_type: ImplementationArgType

The type of the argument

Implementations

source

impl ImplementationArg

source

pub fn matches( &self, arg_type: &Type, registry: &ExtensionsRegistry ) -> Result<bool, SubstraitExprError>

Returns true if an expression of the given type could be used as this argument

There is no “enum” type so enum arguments will only recognize the string type