Struct substrait_expr::builder::schema::FullSchemaBuilder
source · pub struct FullSchemaBuilder { /* private fields */ }Expand description
A builder object for schemas that know both types and names
Implementations
sourceimpl FullSchemaBuilder
impl FullSchemaBuilder
sourcepub fn field(self, name: impl Into<String>, typ: Type) -> Self
pub fn field(self, name: impl Into<String>, typ: Type) -> Self
Add a leaf field with the given name and type
sourcepub fn nested(
self,
name: impl Into<String>,
nullable: bool,
build_func: impl FnOnce(Self) -> Self
) -> Self
pub fn nested( self, name: impl Into<String>, nullable: bool, build_func: impl FnOnce(Self) -> Self ) -> Self
Add a struct field with the given name and children
sourcepub fn build(self) -> SchemaInfo
pub fn build(self) -> SchemaInfo
Consume the builder to create a schema