Struct substrait_expr::builder::schema::NamesOnlySchemaNodeBuilder
source · pub struct NamesOnlySchemaNodeBuilder { /* private fields */ }Expand description
A builder object for a names-only schema
Implementations
sourceimpl NamesOnlySchemaNodeBuilder
impl NamesOnlySchemaNodeBuilder
sourcepub fn new_with_types(registry: ExtensionsRegistry) -> Self
pub fn new_with_types(registry: ExtensionsRegistry) -> Self
Create a new builder with the given type registry
This is an advanced case and only needed if you are trying to maintain type anchors.
sourcepub fn field(self, name: impl Into<String>) -> Self
pub fn field(self, name: impl Into<String>) -> Self
Add a new leaf field to the schema with the given name
sourcepub fn nested(
self,
name: impl Into<String>,
build_func: impl FnOnce(Self) -> Self
) -> Self
pub fn nested( self, name: impl Into<String>, build_func: impl FnOnce(Self) -> Self ) -> Self
Add a new struct field to the schema with the given name
sourcepub fn build(self) -> SchemaInfo
pub fn build(self) -> SchemaInfo
Consume the builder to create a schema