pub struct TypesOnlySchemaBuilder { /* private fields */ }
A builder for creating a types-only schema

Implementations

source

impl TypesOnlySchemaBuilder

source

pub fn new() -> Self

Create a new builder

source

pub fn new_with_types(registry: ExtensionsRegistry) -> Self

Create a new builder with the given type registry

This is an advanced case and only needed if you are trying to maintain type anchors.

source

pub fn field(self, typ: Type) -> Self

Add a new leaf field to the schema of the given type

source

pub fn nested( self, nullable: bool, build_func: impl FnOnce(Self) -> Self ) -> Self

Add a new struct field to the schema

source

pub fn build(self) -> SchemaInfo

Consume the builder to create a schema

source

pub fn types(&self) -> TypeBuilder<'_>

Create a type builder to create user defined types