pub struct UserDefinedTypeBuilder { /* private fields */ }
A builder object for creating a particular user defined type

Implementations

source

impl UserDefinedTypeBuilder

source

pub fn with_nullability(&self, nullable: bool) -> Type

Create an instance of the type with the given nullability

Note, this does not consume the builder and can be called many times.