pub trait SchemaBuildersExt {
    // Required methods
    fn new_names() -> NamesOnlySchemaNodeBuilder;
    fn new_types() -> TypesOnlySchemaBuilder;
    fn new_full() -> FullSchemaBuilder;
}
A trait that adds construction methods to SchemaInfo

Required Methods

source

fn new_names() -> NamesOnlySchemaNodeBuilder

Create a builder that can be used to create a names-only schema

source

fn new_types() -> TypesOnlySchemaBuilder

Create a builder that can be used to create a types-only schema

source

fn new_full() -> FullSchemaBuilder

Create a builder that can be used to create a full schema

Object Safety

This trait is not object safe.

Implementors