pub struct ExpressionsBuilder { /* private fields */ }
A builder object to create expressions

Note that the output of this builder is not an “Expression” message. Expression is not a top-level message in the Substrait specification because an expression references a schema and various extension metadata. Instead, the top level message is ExtendedExpression, which holds a collection of expressions. If you only need to serialize a single expression then you can create an ExtendedExpression that contains a single expression.

Implementations

source

impl ExpressionsBuilder

source

pub fn new(schema: SchemaInfo, params: BuilderParams) -> Self

source

pub fn fields(&self) -> RefBuilder<'_>

source

pub fn functions(&self) -> FunctionsBuilder<'_>

source

pub fn add_expression( &self, output_names: impl IntoExprOutputNames, expression: Expression ) -> Result<&Self, SubstraitExprError>

source

pub fn build(self) -> ExtendedExpression