Enum substrait_expr::error::SubstraitExprError
source · pub enum SubstraitExprError {
InvalidSubstrait(String),
InvalidInput(String),
}Expand description
All errors raised by this crate will be instances of SubstraitExprError
Variants
InvalidSubstrait(String)
This indicates that a substrait message is invalid
InvalidInput(String)
This indicates that a user is trying to do something with the library that is invalid
Implementations
sourceimpl SubstraitExprError
impl SubstraitExprError
sourcepub fn invalid_input(message: impl Into<String>) -> Self
pub fn invalid_input(message: impl Into<String>) -> Self
Shortcut for creating InvalidInput from &str
sourcepub fn invalid_substrait(message: impl Into<String>) -> Self
pub fn invalid_substrait(message: impl Into<String>) -> Self
Shortcut for creating InvalidSubstrait from &str