Modules

  • Methods for creating literals from rust

Traits

  • Extends the protobuf Literal object with useful helper methods
  • A trait that helps convert from rust types to substrait types

Functions