Structs

  • A schema that does not know types or names
  • A schema that knows both the types and names of its fields
  • A field in a schema that knows both types and names
  • Represents a potentially nested schema where we only know the names and not the types of the fields.
  • A field in a names-only schema
  • A schema that knows the types (but not names) of its fields

Enums

  • A schema represents what we know about the input to an expression