pub enum SchemaInfo {
    Empty(EmptySchema),
    Names(NamesOnlySchema),
    Types(TypesOnlySchema),
    Full(FullSchema),
}
A schema represents what we know about the input to an expression

TODO: Expand, copy over content from crate docs

Variants

Implementations

source

impl SchemaInfo

source

pub fn extensions_registry(&self) -> &ExtensionsRegistry

Return a reference to the schema’s extensions registry

This registry keeps track of the user defined types that are referenced by the schema

source

pub fn names_aware(&self) -> bool

Return true if this schema knows the names of its fields

source

pub fn types_aware(&self) -> bool

Return true if this schema knows the types of its fields

source

pub fn len_aware(&self) -> bool

Return true if this schema knows the number of fields

source

pub fn names_dfs<'a>( &'a self ) -> Result<Box<dyn Iterator<Item = &str> + 'a>, SubstraitExprError>

Returns an iterator through the names of the fields, in DFS order

Returns an error if the schema does not know the names of its fields

source

pub fn types_dfs<'a>( &'a self, include_inner: bool ) -> Box<dyn Iterator<Item = Type> + 'a>

Returns an iterator through the types of the fields, in DFS order

If the schema is empty this will return an empty iterator If this schema is names-only the types will all be the unknown type

TODO: Explain include_inner, provide examples

source

pub fn to_substrait(self) -> NamedStruct

Converts to a NamedStruct which is the closest equivalent SubstraitMessage

source

pub fn resolve_type( &self, ref_seg: &ReferenceSegment ) -> Result<Type, SubstraitExprError>

Return the type of the field referenced by ref_seg

Returns an error if the reference does not refer to a field in the schema

If types are not known then the returned type will be the unknown type