Struct substrait_expr::helpers::schema::EmptySchema
source · pub struct EmptySchema { /* private fields */ }Expand description
A schema that does not know types or names
This is also the only schema type that does not know how many fields there are.