Struct substrait_expr::helpers::schema::FullSchemaNode
source · pub struct FullSchemaNode {
pub name: String,
pub type: Type,
pub children: Vec<FullSchemaNode>,
}Expand description
A field in a schema that knows both types and names
Fields
name: StringThe name of the field
This will be the empty string for the root node
type: TypeThe type of the field
children: Vec<FullSchemaNode>The child types