Struct substrait_expr::helpers::schema::NamesOnlySchema
source · pub struct NamesOnlySchema {
pub root: NamesOnlySchemaNode,
/* private fields */
}Expand description
Represents a potentially nested schema where we only know the names and not the types of the fields.
The root of the schema is Vec<NamesOnlySchemaNode> where each node represents
a single (possibly nested) column
Fields
root: NamesOnlySchemaNodeThe root node of the schema
Implementations
sourceimpl NamesOnlySchema
impl NamesOnlySchema
sourcepub fn new(root_nodes: Vec<NamesOnlySchemaNode>) -> Self
pub fn new(root_nodes: Vec<NamesOnlySchemaNode>) -> Self
Create a new names-only schema
sourcepub fn new_with_registry(
root_nodes: Vec<NamesOnlySchemaNode>,
registry: ExtensionsRegistry
) -> Self
pub fn new_with_registry( root_nodes: Vec<NamesOnlySchemaNode>, registry: ExtensionsRegistry ) -> Self
Create a names-only schema with the given registry