Module substrait_expr::helpers::types
source · Constants
- A friendly name that indicates there is no type variation being used
- The name of the unknown type
- The URI of the unknown type
Traits
- Helper methods for substrait Type objects
- This trait helps convert from rust types to substrait types
Functions
- Create an instance of the binary type
- Create an instance of the bool type
- Create an instance of the fp32 type
- Create an instance of the fp64 type
- Create a substrait type from a rust type
- Create an instance of the i8 type
- Create an instance of the i16 type
- Create an instance of the i32 type
- Create an instance of the i64 type
- Create an instance of the string type
- Create an instance of the struct type