pub trait TypeInfer {
    // Required method
    fn as_substrait(nullable: bool) -> Type;
}
This trait helps convert from rust types to substrait types

It’s implemented for all the standard types

Implement this to use methods like from_rust on your own user defined types

Required Methods

source

fn as_substrait(nullable: bool) -> Type

Return an instance of the substrait type for this type

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl TypeInfer for &str

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for &[u8]

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for bool

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for f32

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for f64

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for i8

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for i16

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for i32

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for i64

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for String

source

fn as_substrait(nullable: bool) -> Type

source

impl TypeInfer for Vec<u8>

source

fn as_substrait(nullable: bool) -> Type

Implementors