Struct substrait_expr::builder::functions::FunctionsBuilder
source · pub struct FunctionsBuilder<'a> { /* private fields */ }Expand description
A builder that can create scalar function expressions
Implementations
sourceimpl<'a> FunctionsBuilder<'a>
impl<'a> FunctionsBuilder<'a>
sourcepub fn new_builder(
&self,
func: &'static FunctionDefinition,
args: Vec<Expression>
) -> FunctionBuilder<'_>
pub fn new_builder( &self, func: &'static FunctionDefinition, args: Vec<Expression> ) -> FunctionBuilder<'_>
Creates a new FunctionBuilder based on a given function definition.
This method is not typically used directly. Instead, extension functions
like add or subtract are used which call this function.
However, this could be used directly for UDFs if you don’t want to create an extension trait.
sourcepub fn lookup_field_by_name(&self, name: impl Into<String>) -> Expression
pub fn lookup_field_by_name(&self, name: impl Into<String>) -> Expression
Creates a “late lookup” function expression
This is not really a function call. It’s a placeholder we are currently using to indicate an unresolved field reference. This is created whenever a user creates a field reference by name but the schema is unknown or does not know names.