Struct substrait_expr::builder::functions::ImplementationArg
source · pub struct ImplementationArg {
pub name: String,
pub arg_type: ImplementationArgType,
}Expand description
A named function argument
Fields
name: StringThe name of the argument
This is used for documentation and readability purposes. Consumers don’t generally care what the name is.
arg_type: ImplementationArgTypeThe type of the argument
Implementations
sourceimpl ImplementationArg
impl ImplementationArg
sourcepub fn matches(
&self,
arg_type: &Type,
registry: &ExtensionsRegistry
) -> Result<bool, SubstraitExprError>
pub fn matches( &self, arg_type: &Type, registry: &ExtensionsRegistry ) -> Result<bool, SubstraitExprError>
Returns true if an expression of the given type could be used as this argument
There is no “enum” type so enum arguments will only recognize the string type