Struct substrait_expr::builder::schema::TypeBuilder
source · pub struct TypeBuilder<'a> { /* private fields */ }Expand description
A builder object for creating user defined types
Implementations
sourceimpl<'a> TypeBuilder<'a>
impl<'a> TypeBuilder<'a>
sourcepub fn unknown(&self) -> Type
pub fn unknown(&self) -> Type
Create an instance of the “unknown” type
This is a special type when it comes to function resolution. It will
always match an argument, regardless of what type is expected. However,
if it is present, then the function’s return type changes to unknown as
well.
This type is normally used when the schema is unknown or not type aware.
sourcepub fn user_defined(
&self,
uri: impl Into<String>,
name: impl AsRef<str>
) -> UserDefinedTypeBuilder
pub fn user_defined( &self, uri: impl Into<String>, name: impl AsRef<str> ) -> UserDefinedTypeBuilder
Create a builder that can create instances of a user defined type