Struct substrait_expr::builder::schema::TypesOnlySchemaBuilder
source · pub struct TypesOnlySchemaBuilder { /* private fields */ }Expand description
A builder for creating a types-only schema
Implementations
sourceimpl TypesOnlySchemaBuilder
impl TypesOnlySchemaBuilder
sourcepub fn new_with_types(registry: ExtensionsRegistry) -> Self
pub fn new_with_types(registry: ExtensionsRegistry) -> Self
Create a new builder with the given type registry
This is an advanced case and only needed if you are trying to maintain type anchors.
sourcepub fn nested(
self,
nullable: bool,
build_func: impl FnOnce(Self) -> Self
) -> Self
pub fn nested( self, nullable: bool, build_func: impl FnOnce(Self) -> Self ) -> Self
Add a new struct field to the schema
sourcepub fn build(self) -> SchemaInfo
pub fn build(self) -> SchemaInfo
Consume the builder to create a schema
sourcepub fn types(&self) -> TypeBuilder<'_>
pub fn types(&self) -> TypeBuilder<'_>
Create a type builder to create user defined types