Struct substrait_expr::builder::schema::UserDefinedTypeBuilder
source · pub struct UserDefinedTypeBuilder { /* private fields */ }Expand description
A builder object for creating a particular user defined type
Implementations
sourceimpl UserDefinedTypeBuilder
impl UserDefinedTypeBuilder
sourcepub fn with_nullability(&self, nullable: bool) -> Type
pub fn with_nullability(&self, nullable: bool) -> Type
Create an instance of the type with the given nullability
Note, this does not consume the builder and can be called many times.