Struct substrait_expr::builder::ExpressionsBuilder
source · pub struct ExpressionsBuilder { /* private fields */ }Expand description
A builder object to create expressions
Note that the output of this builder is not an “Expression” message. Expression is not a top-level message in the Substrait specification because an expression references a schema and various extension metadata. Instead, the top level message is ExtendedExpression, which holds a collection of expressions. If you only need to serialize a single expression then you can create an ExtendedExpression that contains a single expression.
Implementations
sourceimpl ExpressionsBuilder
impl ExpressionsBuilder
pub fn new(schema: SchemaInfo, params: BuilderParams) -> Self
pub fn fields(&self) -> RefBuilder<'_>
pub fn functions(&self) -> FunctionsBuilder<'_>
pub fn add_expression( &self, output_names: impl IntoExprOutputNames, expression: Expression ) -> Result<&Self, SubstraitExprError>
pub fn build(self) -> ExtendedExpression