Module substrait_expr::helpers::literals
source · Modules
- Methods for creating literals from rust
Traits
- Extends the protobuf Literal object with useful helper methods
- A trait that helps convert from rust types to substrait types
Functions
- Create a literal from a rust value
- Create a null literal of the given type
- Createa a nullable literal from a rust value (unusual)