Trait substrait_expr::helpers::types::TypeInfer
source · pub trait TypeInfer {
// Required method
fn as_substrait(nullable: bool) -> Type;
}Expand description
This trait helps convert from rust types to substrait types
It’s implemented for all the standard types
Implement this to use methods like
from_rust on your own user defined types
Required Methods
sourcefn as_substrait(nullable: bool) -> Type
fn as_substrait(nullable: bool) -> Type
Return an instance of the substrait type for this type
Object Safety
This trait is not object safe.